==> ltlf2dfa-0.1.2-py3-none-any.whl: ltlf2dfa/Parser.py <==
import ply.yacc as yacc
from Lexer import MyLexer

class MyParser(object):

    def __init__(self):
        self.lexer = MyLexer()
        self.lexer.build()
        self.tokens = self.lexer.tokens
        self.parser = yacc.yacc(module=self)
        self.precedence = (

            ('nonassoc', 'LPAR', 'RPAR'),
            ('left', 'AND', 'OR', 'IMPLIES', 'DIMPLIES', 'UNTIL', 'PASTUNTIL'),
            ('right', 'NEXT', 'EVENTUALLY', 'GLOBALLY', 'PASTNEXT', 'PASTEVENTUALLY', 'PASTGLOBALLY'),
            ('right', 'NOT')
        )

    def __call__(self, s, **kwargs):
        return self.parser.parse(s, lexer=self.lexer.lexer)

    def p_formula(self, p):
        '''
        formula : formula AND formula
                | formula OR formula
                | formula IMPLIES formula
                | formula DIMPLIES formula
                | formula UNTIL formula
                | formula PASTUNTIL formula
                | NEXT formula
                | EVENTUALLY formula
                | GLOBALLY formula
                | PASTNEXT formula
                | PASTEVENTUALLY formula
                | PASTGLOBALLY formula
                | NOT formula
                | TRUE
                | FALSE
                | TERM
        '''

        if len(p) == 2: p[0] = p[1]
        elif len(p) == 3:
            if p[1] == 'E': # eventually A == true UNITL A
                p[0] = ('U','T', p[2])
            elif p[1] == 'G': # globally A == not( eventually (not A) )
                p[0] = ('~',('U', 'T', ('~',p[2])))
            elif p[1] == 'O': # pasteventually A = true SINCE A
                p[0] = ('S','T', p[2])
            elif p[1] == 'H': # pastglobally A == not( pasteventually (not A) )
                p[0] = ('~',('S', 'T', ('~',p[2])))
            else:
                p[0] = (p[1], p[2])
        elif len(p) == 4:
            if p[2] == '->':
                p[0] = ('|', ('~', p[1]), p[3])
            elif p[2] == '<->':
                p[0] = ('&', ('|', ('~', p[1]), p[3]), ('|', ('~', p[3]), p[1]))
            else:
                p[0] = (p[2],p[1],p[3])
        else: raise ValueError


    def p_expr_group(self, p):
        '''
        formula : LPAR formula RPAR
        '''
        p[0] = p[2]

    def p_error(self, p):
        raise ValueError("Syntax error in input! %s" %str(p))

# if __name__ == '__main__':
#     par = MyParser()
#     while True:
#        try:
#            s = input('calc > ')
#        except EOFError:
#            break
#        if not s: continue
#        result = par(s)
#        print(result)

==> ltlf2dfa-0.2.1-py3-none-any.whl: ltlf2dfa/Parser.py <==
import ply.yacc as yacc
from ltlf2dfa.Lexer import MyLexer

class MyParser(object):

    def __init__(self):
        self.lexer = MyLexer()
        self.lexer.build()
        self.tokens = self.lexer.tokens
        self.parser = yacc.yacc(module=self)
        self.precedence = (

            ('nonassoc', 'LPAR', 'RPAR'),
            ('left', 'AND', 'OR', 'IMPLIES', 'DIMPLIES', 'UNTIL', 'RELEASE', 'PASTUNTIL'),
            ('right', 'NEXT', 'WEAKNEXT', 'EVENTUALLY', 'GLOBALLY', 'PASTNEXT', 'PASTEVENTUALLY', 'PASTGLOBALLY'),
            ('right', 'NOT')
        )

    def __call__(self, s, **kwargs):
        return self.parser.parse(s, lexer=self.lexer.lexer)

    def p_formula(self, p):
        '''
        formula : formula AND formula
                | formula OR formula
                | formula IMPLIES formula
                | formula DIMPLIES formula
                | formula UNTIL formula
                | formula RELEASE formula
                | formula PASTUNTIL formula
                | NEXT formula
                | WEAKNEXT formula
                | EVENTUALLY formula
                | GLOBALLY formula
                | PASTNEXT formula
                | PASTEVENTUALLY formula
                | PASTGLOBALLY formula
                | NOT formula
                | TRUE
                | FALSE
                | TERM
        '''

        if len(p) == 2: p[0] = p[1]
        elif len(p) == 3:
            if p[1] == 'F': # eventually A == true UNITL A
                p[0] = ('U','true', p[2])
            elif p[1] == 'G': # globally A == not( eventually (not A) )
                p[0] = ('~',('U', 'true', ('~',p[2])))
            elif p[1] == 'O': # pasteventually A = true SINCE A
                p[0] = ('S','true', p[2])
            elif p[1] == 'H': # pastglobally A == not( pasteventually (not A) )
                p[0] = ('~',('S', 'true', ('~',p[2])))
            elif p[1] == 'W':
                p[0] = ('~', ('X', ('~', p[1])))
            else:
                p[0] = (p[1], p[2])
        elif len(p) == 4:
            if p[2] == '->':
                p[0] = ('|', ('~', p[1]), p[3])
            elif p[2] == '<->':
                p[0] = ('&', ('|', ('~', p[1]), p[3]), ('|', ('~', p[3]), p[1]))
            elif p[2] == 'R':
                p[0] = ('~', ('U', ('~', p[1]), ('~', p[3])))
            else:
                p[0] = (p[2],p[1],p[3])
        else: raise ValueError


    def p_expr_group(self, p):
        '''
        formula : LPAR formula RPAR
        '''
        p[0] = p[2]

    def p_error(self, p):
        raise ValueError("Syntax error in input! %s" %str(p))

# if __name__ == '__main__':
#     par = MyParser()
#     while True:
#        try:
#            s = input('calc > ')
#        except EOFError:
#            break
#        if not s: continue
#        result = par(s)
#        print(result)
